library(tidyverse)
homes <- readRDS(url("http://people.virginia.edu/~jcf2d/data/albemarle_homes.rds"))

# focus on 6 cities
vars <- c("CHARLOTTESVILLE", "CROZET", "EARLYSVILLE", 
          "KESWICK", "SCOTTSVILLE", "NORTH GARDEN")

# filter for our cities of interest and homes with at least 1 bedroom and 1 bathroom
homes <- homes %>% 
  filter(city %in% vars & Bedroom > 0 & FullBath > 0)

# drop unusued levels for city
homes$city <- droplevels(homes$city)

# plot TotalValue vs FinSqFt
ggplot(homes, aes(x = FinSqFt, y = TotalValue)) +
  geom_point(alpha = 0.3) +
  scale_x_continuous(labels = scales::comma) +
  scale_y_continuous(labels = scales::dollar) +
  coord_cartesian(xlim = c(1500, 3000), ylim = c(1e5, 1e6)) 


